<?php
namespace PHPWord\Tests;

use PHPWord;
use DOMDocument;

class TestHelper
{
    /**
     * @param \PHPWord $PHPWord
     * @return \PHPWord\Tests\Doc
     */
    public static function getDocument(PHPWord $PHPWord)
    {
        $objWriter = \PHPWord_IOFactory::createWriter($PHPWord, 'Word2007');
        $objWriter->save(__DIR__ . '/Tests/_files/test.docx');

        $zip = new \ZipArchive;
        $res = $zip->open(__DIR__ . '/Tests/_files/test.docx');
        if ($res === true) {
            $zip->extractTo(__DIR__ . '/Tests/_files/test/');
            $zip->close();
        }

        return new Doc(__DIR__ . '/Tests/_files/test/');
    }

    public static function clear()
    {
        unlink(__DIR__ . '/Tests/_files/test.docx');
        self::deleteDir(__DIR__ . '/Tests/_files/test/');
    }

    /**
     * @param string $dir
     */
    public static function deleteDir($dir)
    {
        foreach (scandir($dir) as $file) {
            if ($file === '.' || $file === '..') {
                continue;
            } else if (is_file($dir . "/" . $file)) {
                unlink($dir . "/" . $file);
            } else if (is_dir($dir . "/" . $file)) {
                self::deleteDir($dir . "/" . $file);
            }
        }

        rmdir($dir);
    }
}

class Doc
{
    /** @var string $path */
    private $path;

    /** @var \DOMDocument $dom */
    private $dom;

    /** @var \DOMXpath $xpath */
    private $xpath;

    /** @var string $file */
    private $file;

    /**
     * @param string $path
     */
    public function __construct($path)
    {
        $this->path = realpath($path);
    }

    /**
     * @param string $file
     * @return \DOMDocument
     */
    public function getFileDom($file = 'word/document.xml')
    {
        if (null !== $this->dom && $file === $this->file) {
            return $this->dom;
        }

        $this->xpath = null;
        $this->file = $file;

        $file = $this->path . '/' . $file;
        $this->dom = new DOMDocument();
        $this->dom->load($file);
        return $this->dom;
    }

    /**
     * @param string $path
     * @param string $file
     * @return \DOMElement
     */
    public function getElement($path, $file = 'word/document.xml')
    {
        if ($this->dom === null || $file !== $this->file) {
            $this->getFileDom($file);
        }

        if (null === $this->xpath) {
            $this->xpath = new \DOMXpath($this->dom);

        }

        $elements = $this->xpath->query($path);
        return $elements->item(0);
    }
}